slepc-3.18.0 2022-10-01
Report Typos and Errors

# FNDestroy

Destroys FN context that was created with FNCreate().

### Synopsis

    #include "slepcfn.h"
    PetscErrorCode FNDestroy(FN *fn)

Collective on fn

### Input Parameter

| fn | - the math function context

### See Also

FNCreate()

### Level

beginner

### Location

src/sys/classes/fn/interface/fnbasic.c

### Examples

src/nep/tutorials/ex22.c.html
src/nep/tutorials/ex22f90.F90.html
src/nep/tutorials/ex27.c.html
src/nep/tutorials/ex27f90.F90.html
src/nep/tutorials/ex42.c.html
src/nep/tutorials/nlevp/gun.c.html
src/nep/tutorials/nlevp/loaded_string.c.html
src/mfn/tutorials/ex39.c.html
Index of all FN routines
Table of Contents for all manual pages
Index of all manual pages